
**Modules**

.. autosummary::
   :nosignatures:

   soxspipe.commonutils
   soxspipe.recipes 
   soxspipe.commonutils.polynomials
   soxspipe.commonutils.toolkit
   soxspipe.docstring_test
   soxspipe.utKit

**Classes**

.. autosummary::
   :nosignatures:

   soxspipe.commonutils.create_dispersion_map
   soxspipe.commonutils.detect_continuum
   soxspipe.commonutils.detect_order_edges
   soxspipe.commonutils.detector_lookup
   soxspipe.commonutils.keyword_lookup
   soxspipe.commonutils.polynomials.chebyshev_order_wavelength_polynomials
   soxspipe.commonutils.polynomials.chebyshev_order_xy_polynomials
   soxspipe.commonutils.polynomials.chebyshev_xy_polynomial
   soxspipe.commonutils.subtract_background
   soxspipe.commonutils.subtract_sky
   soxspipe.recipes.soxs_disp_solution
   soxspipe.recipes.soxs_mbias
   soxspipe.recipes.soxs_mdark
   soxspipe.recipes.soxs_mflat
   soxspipe.recipes.soxs_nod_mode
   soxspipe.recipes.soxs_order_centres
   soxspipe.recipes.soxs_spatial_solution
   soxspipe.recipes.soxs_stare
   soxspipe.recipes.soxs_straighten 

**Functions**

.. autosummary::
   :nosignatures:

   soxspipe.commonutils.dispersion_map_to_pixel_arrays
   soxspipe.commonutils.filenamer
   soxspipe.commonutils.getpackagepath
   soxspipe.commonutils.toolkit.cut_image_slice
   soxspipe.commonutils.toolkit.generic_quality_checks
   soxspipe.commonutils.toolkit.get_calibrations_path
   soxspipe.commonutils.toolkit.quicklook_image
   soxspipe.commonutils.toolkit.read_spectral_format
   soxspipe.commonutils.toolkit.spectroscopic_image_quality_checks
   soxspipe.commonutils.toolkit.twoD_disp_map_image_to_dataframe
   soxspipe.commonutils.toolkit.unpack_order_table
   soxspipe.docstring_test.docsting_test 
